@@ -18,6 +18,7 @@ import kubify.up as kubify_up
 
 import kubify.down as kubify_down
 import kubify.start as kubify_start
+import kubify.start_all as kubify_start_all
 
 import kubify.src.aws_constants as aws_constants
 
@@ -84,6 +85,11 @@ def start():  # start service in rapid testing coding mode
     kubify_start_class.start()
 
 
+def start_all():  # start service in rapid testing coding mode
+    kubify_start_all_class = kubify_start_all.StartAll()
+    kubify_start_all_class.start_all()
+
+
 # def generate_certs():
 #     path = Path(f"{app_constants.kubify_work}/certs/ca.key")
 #     if not path.is_file():
